The hardware and bandwidth for this mirror is donated by dogado GmbH, the Webhosting and Full Service-Cloud Provider. Check out our Wordpress Tutorial.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]dogado.de.

Package {tinydng}


Type: Package
Title: 'TinyDNG' C++ Header Files
Version: 0.1.0-0
Description: Provides C++ header files for 'TinyDNG', a small header-only library for reading and writing 'DNG' and 'TIFF' files.
License: MIT + file LICENSE
URL: https://github.com/tylermorganwall/tinydng
BugReports: https://github.com/tylermorganwall/tinydng/issues
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2026-06-05 02:29:35 UTC; tyler
Author: Tyler Morgan-Wall ORCID iD [aut, cre, cph], Syoyo Fujita [aut, cph] (Original author of TinyDNG)
Maintainer: Tyler Morgan-Wall <tylermw@gmail.com>
Repository: CRAN
Date/Publication: 2026-06-09 16:10:02 UTC

'TinyDNG' C++ Header Files

Description

Provides C++ header files for TinyDNG.

Details

To use these headers from another R package, add this to DESCRIPTION:

LinkingTo: tinydng

and include the headers in C++ code with:

#include <tinydng/tiny_dng_loader.h>
#include <tinydng/tiny_dng_writer.h>

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.
Health stats visible at Monitor.